@@ -27,6 +27,9 @@ pub enum DispatchEvent {
     GuildEmojisUpdate(GuildEmojisUpdate),
     GuildIntegrationsUpdate(GuildIntegrationsUpdate),
     GuildUpdate(Box<GuildUpdate>),
+    IntegrationCreate(Box<IntegrationCreate>),
+    IntegrationDelete(IntegrationDelete),
+    IntegrationUpdate(Box<IntegrationUpdate>),
     InviteCreate(Box<InviteCreate>),
     InviteDelete(InviteDelete),
     MemberAdd(Box<MemberAdd>),
@@ -48,6 +51,9 @@ pub enum DispatchEvent {
     RoleCreate(RoleCreate),
     RoleDelete(RoleDelete),
     RoleUpdate(RoleUpdate),
+    StageInstanceCreate(StageInstanceCreate),
+    StageInstanceDelete(StageInstanceDelete),
+    StageInstanceUpdate(StageInstanceUpdate),
     TypingStart(Box<TypingStart>),
     UnavailableGuild(UnavailableGuild),
     UserUpdate(UserUpdate),
@@ -72,6 +78,9 @@ impl DispatchEvent {
             Self::GuildEmojisUpdate(_) => EventType::GuildEmojisUpdate,
             Self::GuildIntegrationsUpdate(_) => EventType::GuildIntegrationsUpdate,
             Self::GuildUpdate(_) => EventType::GuildUpdate,
+            Self::IntegrationCreate(_) => EventType::IntegrationCreate,
+            Self::IntegrationDelete(_) => EventType::IntegrationDelete,
+            Self::IntegrationUpdate(_) => EventType::IntegrationUpdate,
             Self::InviteCreate(_) => EventType::InviteCreate,
             Self::InviteDelete(_) => EventType::InviteDelete,
             Self::MemberAdd(_) => EventType::MemberAdd,
@@ -93,6 +102,9 @@ impl DispatchEvent {
             Self::RoleCreate(_) => EventType::RoleCreate,
             Self::RoleDelete(_) => EventType::RoleDelete,
             Self::RoleUpdate(_) => EventType::RoleUpdate,
+            Self::StageInstanceCreate(_) => EventType::StageInstanceCreate,
+            Self::StageInstanceDelete(_) => EventType::StageInstanceDelete,
+            Self::StageInstanceUpdate(_) => EventType::StageInstanceUpdate,
             Self::TypingStart(_) => EventType::TypingStart,
             Self::UnavailableGuild(_) => EventType::UnavailableGuild,
             Self::UserUpdate(_) => EventType::UserUpdate,
@@ -120,6 +132,9 @@ impl TryFrom<Event> for DispatchEvent {
             Event::GuildEmojisUpdate(v) => Self::GuildEmojisUpdate(v),
             Event::GuildIntegrationsUpdate(v) => Self::GuildIntegrationsUpdate(v),
             Event::GuildUpdate(v) => Self::GuildUpdate(v),
+            Event::IntegrationCreate(v) => Self::IntegrationCreate(v),
+            Event::IntegrationDelete(v) => Self::IntegrationDelete(v),
+            Event::IntegrationUpdate(v) => Self::IntegrationUpdate(v),
             Event::InviteCreate(v) => Self::InviteCreate(v),
             Event::InviteDelete(v) => Self::InviteDelete(v),
             Event::MemberAdd(v) => Self::MemberAdd(v),
@@ -141,6 +156,9 @@ impl TryFrom<Event> for DispatchEvent {
             Event::RoleCreate(v) => Self::RoleCreate(v),
             Event::RoleDelete(v) => Self::RoleDelete(v),
             Event::RoleUpdate(v) => Self::RoleUpdate(v),
+            Event::StageInstanceCreate(v) => Self::StageInstanceCreate(v),
+            Event::StageInstanceDelete(v) => Self::StageInstanceDelete(v),
+            Event::StageInstanceUpdate(v) => Self::StageInstanceUpdate(v),
             Event::TypingStart(v) => Self::TypingStart(v),
             Event::UnavailableGuild(v) => Self::UnavailableGuild(v),
             Event::UserUpdate(v) => Self::UserUpdate(v),
@@ -227,6 +245,15 @@ impl<'de, 'a> DeserializeSeed<'de> for DispatchEventWithTypeDeserializer<'a> {
             "GUILD_UPDATE" => {
                 DispatchEvent::GuildUpdate(Box::new(GuildUpdate::deserialize(deserializer)?))
             }
+            "INTEGRATION_CREATE" => DispatchEvent::IntegrationCreate(Box::new(
+                IntegrationCreate::deserialize(deserializer)?,
+            )),
+            "INTEGRATION_DELETE" => {
+                DispatchEvent::IntegrationDelete(IntegrationDelete::deserialize(deserializer)?)
+            }
+            "INTEGRATION_UPDATE" => DispatchEvent::IntegrationUpdate(Box::new(
+                IntegrationUpdate::deserialize(deserializer)?,
+            )),
             "INVITE_CREATE" => {
                 DispatchEvent::InviteCreate(Box::new(InviteCreate::deserialize(deserializer)?))
             }
@@ -271,6 +298,15 @@ impl<'de, 'a> DeserializeSeed<'de> for DispatchEventWithTypeDeserializer<'a> {
 
                 DispatchEvent::Resumed
             }
+            "STAGE_INSTANCE_CREATE" => {
+                DispatchEvent::StageInstanceCreate(StageInstanceCreate::deserialize(deserializer)?)
+            }
+            "STAGE_INSTANCE_DELETE" => {
+                DispatchEvent::StageInstanceDelete(StageInstanceDelete::deserialize(deserializer)?)
+            }
+            "STAGE_INSTANCE_UPDATE" => {
+                DispatchEvent::StageInstanceUpdate(StageInstanceUpdate::deserialize(deserializer)?)
+            }
             "TYPING_START" => {
                 DispatchEvent::TypingStart(Box::new(TypingStart::deserialize(deserializer)?))
             }
