@@ -579,7 +579,7 @@ mod tests {
     "max_presences": null,
     "mfa_level": 0,
     "name": "FooBaz",
-    "nsfw": false,
+    "nsfw_level": 1,
     "owner_id": "13311",
     "preferred_locale": "en-US",
     "premium_subscription_count": 4,
@@ -649,7 +649,7 @@ mod tests {
     "max_presences": null,
     "mfa_level": 0,
     "name": "FooBar",
-    "nsfw": false,
+    "nsfw_level": 0,
     "owner_id": "46",
     "preferred_locale": "en-US",
     "premium_subscription_count": null,
