@@ -24,6 +24,9 @@ pub enum EventType {
     GuildEmojisUpdate,
     GuildIntegrationsUpdate,
     GuildUpdate,
+    IntegrationCreate,
+    IntegrationDelete,
+    IntegrationUpdate,
     InviteCreate,
     InviteDelete,
     #[serde(rename = "GUILD_MEMBER_ADD")]
@@ -63,6 +66,9 @@ pub enum EventType {
     ShardReconnecting,
     ShardPayload,
     ShardResuming,
+    StageInstanceCreate,
+    StageInstanceDelete,
+    StageInstanceUpdate,
     TypingStart,
     UnavailableGuild,
     UserUpdate,
@@ -86,6 +92,9 @@ impl EventType {
             Self::GuildEmojisUpdate => Some("GUILD_EMOJIS_UPDATE"),
             Self::GuildIntegrationsUpdate => Some("GUILD_INTEGRATIONS_UPDATE"),
             Self::GuildUpdate => Some("GUILD_UPDATE"),
+            Self::IntegrationCreate => Some("INTEGRATION_CREATE"),
+            Self::IntegrationDelete => Some("INTEGRATION_DELETE"),
+            Self::IntegrationUpdate => Some("INTEGRATION_UPDATE"),
             Self::InviteCreate => Some("INVITE_CREATE"),
             Self::InviteDelete => Some("INVITE_DELETE"),
             Self::MemberAdd => Some("GUILD_MEMBER_ADD"),
@@ -107,6 +116,9 @@ impl EventType {
             Self::RoleCreate => Some("GUILD_ROLE_CREATE"),
             Self::RoleDelete => Some("GUILD_ROLE_DELETE"),
             Self::RoleUpdate => Some("GUILD_ROLE_UPDATE"),
+            Self::StageInstanceCreate => Some("STAGE_INSTANCE_CREATE"),
+            Self::StageInstanceDelete => Some("STAGE_INSTANCE_DELETE"),
+            Self::StageInstanceUpdate => Some("STAGE_INSTANCE_UPDATE"),
             Self::TypingStart => Some("TYPING_START"),
             Self::UnavailableGuild => Some("UNAVAILABLE_GUILD"),
             Self::UserUpdate => Some("USER_UPDATE"),
@@ -146,6 +158,9 @@ impl<'a> TryFrom<&'a str> for EventType {
             "GUILD_EMOJIS_UPDATE" => Ok(Self::GuildEmojisUpdate),
             "GUILD_INTEGRATIONS_UPDATE" => Ok(Self::GuildIntegrationsUpdate),
             "GUILD_UPDATE" => Ok(Self::GuildUpdate),
+            "INTEGRATION_CREATE" => Ok(Self::IntegrationCreate),
+            "INTEGRATION_DELETE" => Ok(Self::IntegrationDelete),
+            "INTEGRATION_UPDATE" => Ok(Self::IntegrationUpdate),
             "INVITE_CREATE" => Ok(Self::InviteCreate),
             "INVITE_DELETE" => Ok(Self::InviteDelete),
             "GUILD_MEMBER_ADD" => Ok(Self::MemberAdd),
@@ -167,6 +182,9 @@ impl<'a> TryFrom<&'a str> for EventType {
             "GUILD_ROLE_CREATE" => Ok(Self::RoleCreate),
             "GUILD_ROLE_DELETE" => Ok(Self::RoleDelete),
             "GUILD_ROLE_UPDATE" => Ok(Self::RoleUpdate),
+            "STAGE_INSTANCE_CREATE" => Ok(Self::StageInstanceCreate),
+            "STAGE_INSTANCE_DELETE" => Ok(Self::StageInstanceDelete),
+            "STAGE_INSTANCE_UPDATE" => Ok(Self::StageInstanceUpdate),
             "TYPING_START" => Ok(Self::TypingStart),
             "UNAVAILABLE_GUILD" => Ok(Self::UnavailableGuild),
             "USER_UPDATE" => Ok(Self::UserUpdate),
@@ -218,6 +236,9 @@ mod tests {
             "GUILD_INTEGRATIONS_UPDATE",
         );
         assert_variant(EventType::GuildUpdate, "GUILD_UPDATE");
+        assert_variant(EventType::IntegrationCreate, "INTEGRATION_CREATE");
+        assert_variant(EventType::IntegrationDelete, "INTEGRATION_DELETE");
+        assert_variant(EventType::IntegrationUpdate, "INTEGRATION_UPDATE");
         assert_variant(EventType::InviteCreate, "INVITE_CREATE");
         assert_variant(EventType::InviteDelete, "INVITE_DELETE");
         assert_variant(EventType::MemberAdd, "GUILD_MEMBER_ADD");
@@ -249,6 +270,9 @@ mod tests {
         assert_variant(EventType::ShardPayload, "SHARD_PAYLOAD");
         assert_variant(EventType::ShardReconnecting, "SHARD_RECONNECTING");
         assert_variant(EventType::ShardResuming, "SHARD_RESUMING");
+        assert_variant(EventType::StageInstanceCreate, "STAGE_INSTANCE_CREATE");
+        assert_variant(EventType::StageInstanceDelete, "STAGE_INSTANCE_DELETE");
+        assert_variant(EventType::StageInstanceUpdate, "STAGE_INSTANCE_UPDATE");
         assert_variant(EventType::TypingStart, "TYPING_START");
         assert_variant(EventType::UnavailableGuild, "UNAVAILABLE_GUILD");
         assert_variant(EventType::UserUpdate, "USER_UPDATE");
