@@ -59,6 +59,12 @@ pub enum Event {
     GuildIntegrationsUpdate(GuildIntegrationsUpdate),
     /// A guild was updated.
     GuildUpdate(Box<GuildUpdate>),
+    /// A guild integration was created.
+    IntegrationCreate(Box<IntegrationCreate>),
+    /// A guild integration was updated.
+    IntegrationDelete(IntegrationDelete),
+    /// A guild integration was deleted.
+    IntegrationUpdate(Box<IntegrationUpdate>),
     /// A invite was made.
     InviteCreate(Box<InviteCreate>),
     /// A invite was deleted.
@@ -121,6 +127,12 @@ pub enum Event {
     ShardPayload(Payload),
     /// A shard is now in a Resuming stage after a disconnect.
     ShardResuming(Resuming),
+    /// A stage instance was created in a stage channel.
+    StageInstanceCreate(StageInstanceCreate),
+    /// A stage instance was deleted in a stage channel.
+    StageInstanceDelete(StageInstanceDelete),
+    /// A stage instance was updated in a stage channel.
+    StageInstanceUpdate(StageInstanceUpdate),
     /// A user started typing in a channel.
     TypingStart(Box<TypingStart>),
     /// A guild is now unavailable.
@@ -155,6 +167,9 @@ impl Event {
             Self::GuildEmojisUpdate(_) => EventType::GuildEmojisUpdate,
             Self::GuildIntegrationsUpdate(_) => EventType::GuildIntegrationsUpdate,
             Self::GuildUpdate(_) => EventType::GuildUpdate,
+            Self::IntegrationCreate(_) => EventType::IntegrationCreate,
+            Self::IntegrationDelete(_) => EventType::IntegrationDelete,
+            Self::IntegrationUpdate(_) => EventType::IntegrationUpdate,
             Self::InviteCreate(_) => EventType::InviteCreate,
             Self::InviteDelete(_) => EventType::InviteDelete,
             Self::MemberAdd(_) => EventType::MemberAdd,
@@ -183,6 +198,9 @@ impl Event {
             Self::ShardReconnecting(_) => EventType::ShardReconnecting,
             Self::ShardPayload(_) => EventType::ShardPayload,
             Self::ShardResuming(_) => EventType::ShardResuming,
+            Self::StageInstanceCreate(_) => EventType::StageInstanceCreate,
+            Self::StageInstanceDelete(_) => EventType::StageInstanceDelete,
+            Self::StageInstanceUpdate(_) => EventType::StageInstanceUpdate,
             Self::TypingStart(_) => EventType::TypingStart,
             Self::UnavailableGuild(_) => EventType::UnavailableGuild,
             Self::UserUpdate(_) => EventType::UserUpdate,
@@ -207,6 +225,9 @@ impl From<Box<DispatchEvent>> for Event {
             DispatchEvent::GuildDelete(v) => Self::GuildDelete(v),
             DispatchEvent::GuildEmojisUpdate(v) => Self::GuildEmojisUpdate(v),
             DispatchEvent::GuildIntegrationsUpdate(v) => Self::GuildIntegrationsUpdate(v),
+            DispatchEvent::IntegrationCreate(v) => Self::IntegrationCreate(v),
+            DispatchEvent::IntegrationDelete(v) => Self::IntegrationDelete(v),
+            DispatchEvent::IntegrationUpdate(v) => Self::IntegrationUpdate(v),
             DispatchEvent::InviteCreate(v) => Self::InviteCreate(v),
             DispatchEvent::InviteDelete(v) => Self::InviteDelete(v),
             DispatchEvent::MemberAdd(v) => Self::MemberAdd(v),
@@ -229,6 +250,9 @@ impl From<Box<DispatchEvent>> for Event {
             DispatchEvent::ReactionRemoveEmoji(v) => Self::ReactionRemoveEmoji(v),
             DispatchEvent::Ready(v) => Self::Ready(v),
             DispatchEvent::Resumed => Self::Resumed,
+            DispatchEvent::StageInstanceCreate(v) => Self::StageInstanceCreate(v),
+            DispatchEvent::StageInstanceDelete(v) => Self::StageInstanceDelete(v),
+            DispatchEvent::StageInstanceUpdate(v) => Self::StageInstanceUpdate(v),
             DispatchEvent::TypingStart(v) => Self::TypingStart(v),
             DispatchEvent::UnavailableGuild(v) => Self::UnavailableGuild(v),
             DispatchEvent::UserUpdate(v) => Self::UserUpdate(v),
