@@ -11,6 +11,7 @@ mod integration_account;
 mod integration_application;
 mod integration_expire_behavior;
 mod mfa_level;
+mod nsfw_level;
 mod partial_guild;
 mod partial_member;
 mod permissions;
@@ -29,9 +30,9 @@ pub use self::{
     explicit_content_filter::ExplicitContentFilter, info::GuildInfo, integration::GuildIntegration,
     integration_account::IntegrationAccount, integration_application::IntegrationApplication,
     integration_expire_behavior::IntegrationExpireBehavior, member::Member, mfa_level::MfaLevel,
-    partial_guild::PartialGuild, partial_member::PartialMember, permissions::Permissions,
-    premium_tier::PremiumTier, preview::GuildPreview, prune::GuildPrune, role::Role,
-    role_tags::RoleTags, system_channel_flags::SystemChannelFlags,
+    nsfw_level::NSFWLevel, partial_guild::PartialGuild, partial_member::PartialMember,
+    permissions::Permissions, premium_tier::PremiumTier, preview::GuildPreview, prune::GuildPrune,
+    role::Role, role_tags::RoleTags, system_channel_flags::SystemChannelFlags,
     unavailable_guild::UnavailableGuild, verification_level::VerificationLevel,
     widget::GuildWidget,
 };
@@ -39,7 +40,7 @@ pub use self::{
 use self::member::MemberListDeserializer;
 use super::gateway::presence::PresenceListDeserializer;
 use crate::{
-    channel::GuildChannel,
+    channel::{GuildChannel, StageInstance},
     gateway::presence::Presence,
     id::{ApplicationId, ChannelId, GuildId, UserId},
     voice::voice_state::VoiceState,
@@ -85,7 +86,10 @@ pub struct Guild {
     pub members: Vec<Member>,
     pub mfa_level: MfaLevel,
     pub name: String,
+    #[deprecated(since = "0.4.3", note = "no longer provided by discord, see #839")]
+    #[serde(skip)]
     pub nsfw: bool,
+    pub nsfw_level: NSFWLevel,
     pub owner_id: UserId,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub owner: Option<bool>,
@@ -98,10 +102,13 @@ pub struct Guild {
     pub premium_tier: PremiumTier,
     #[serde(default)]
     pub presences: Vec<Presence>,
+    #[deprecated(since = "0.4.3", note = "no longer provided by discord, see #884")]
     pub region: String,
     pub roles: Vec<Role>,
     pub rules_channel_id: Option<ChannelId>,
     pub splash: Option<String>,
+    #[serde(skip_serializing_if = "Vec::is_empty")]
+    pub stage_instances: Vec<StageInstance>,
     pub system_channel_flags: SystemChannelFlags,
     pub system_channel_id: Option<ChannelId>,
     #[serde(default)]
@@ -146,7 +153,7 @@ impl<'de> Deserialize<'de> for Guild {
             Members,
             MfaLevel,
             Name,
-            Nsfw,
+            NsfwLevel,
             OwnerId,
             Owner,
             Permissions,
@@ -157,6 +164,7 @@ impl<'de> Deserialize<'de> for Guild {
             Region,
             Roles,
             Splash,
+            StageInstances,
             SystemChannelFlags,
             SystemChannelId,
             RulesChannelId,
@@ -203,7 +211,7 @@ impl<'de> Deserialize<'de> for Guild {
                 let mut members = None;
                 let mut mfa_level = None;
                 let mut name = None;
-                let mut nsfw = None;
+                let mut nsfw_level = None;
                 let mut owner = None::<Option<_>>;
                 let mut owner_id = None;
                 let mut permissions = None::<Option<_>>;
@@ -214,6 +222,7 @@ impl<'de> Deserialize<'de> for Guild {
                 let mut region = None;
                 let mut roles = None;
                 let mut splash = None::<Option<_>>;
+                let mut stage_instances = None::<Vec<StageInstance>>;
                 let mut system_channel_id = None::<Option<_>>;
                 let mut system_channel_flags = None;
                 let mut rules_channel_id = None::<Option<_>>;
@@ -421,12 +430,12 @@ impl<'de> Deserialize<'de> for Guild {
 
                             name = Some(map.next_value()?);
                         }
-                        Field::Nsfw => {
-                            if nsfw.is_some() {
-                                return Err(DeError::duplicate_field("nsfw"));
+                        Field::NsfwLevel => {
+                            if nsfw_level.is_some() {
+                                return Err(DeError::duplicate_field("nsfw_level"));
                             }
 
-                            nsfw = Some(map.next_value()?);
+                            nsfw_level = Some(map.next_value()?);
                         }
                         Field::Owner => {
                             if owner.is_some() {
@@ -500,6 +509,13 @@ impl<'de> Deserialize<'de> for Guild {
 
                             splash = Some(map.next_value()?);
                         }
+                        Field::StageInstances => {
+                            if stage_instances.is_some() {
+                                return Err(DeError::duplicate_field("stage_instances"));
+                            }
+
+                            stage_instances = Some(map.next_value()?);
+                        }
                         Field::SystemChannelId => {
                             if system_channel_id.is_some() {
                                 return Err(DeError::duplicate_field("system_channel_id"));
@@ -603,7 +619,7 @@ impl<'de> Deserialize<'de> for Guild {
                 let max_video_channel_users = max_video_channel_users.unwrap_or_default();
                 let member_count = member_count.unwrap_or_default();
                 let mut members = members.unwrap_or_default();
-                let nsfw = nsfw.unwrap_or_default();
+                let nsfw_level = nsfw_level.ok_or_else(|| DeError::missing_field("nsfw_level"))?;
                 let owner = owner.unwrap_or_default();
                 let permissions = permissions.unwrap_or_default();
                 let premium_subscription_count = premium_subscription_count.unwrap_or_default();
@@ -611,6 +627,7 @@ impl<'de> Deserialize<'de> for Guild {
                 let mut presences = presences.unwrap_or_default();
                 let rules_channel_id = rules_channel_id.unwrap_or_default();
                 let splash = splash.unwrap_or_default();
+                let stage_instances = stage_instances.unwrap_or_default();
                 let system_channel_id = system_channel_id.unwrap_or_default();
                 let unavailable = unavailable.unwrap_or_default();
                 let vanity_url_code = vanity_url_code.unwrap_or_default();
@@ -658,6 +675,7 @@ impl<'de> Deserialize<'de> for Guild {
                     ?rules_channel_id,
                     ?roles,
                     ?splash,
+                    ?stage_instances,
                     ?system_channel_flags,
                     ?system_channel_id,
                     ?unavailable,
@@ -694,6 +712,7 @@ impl<'de> Deserialize<'de> for Guild {
                     voice_state.guild_id.replace(id);
                 }
 
+                #[allow(deprecated)]
                 Ok(Guild {
                     afk_channel_id,
                     afk_timeout,
@@ -719,7 +738,8 @@ impl<'de> Deserialize<'de> for Guild {
                     members,
                     mfa_level,
                     name,
-                    nsfw,
+                    nsfw: false,
+                    nsfw_level,
                     owner_id,
                     owner,
                     permissions,
@@ -731,6 +751,7 @@ impl<'de> Deserialize<'de> for Guild {
                     roles,
                     rules_channel_id,
                     splash,
+                    stage_instances,
                     system_channel_flags,
                     system_channel_id,
                     unavailable,
@@ -768,7 +789,7 @@ impl<'de> Deserialize<'de> for Guild {
             "members",
             "mfa_level",
             "name",
-            "nsfw",
+            "nsfw_level",
             "owner",
             "owner_id",
             "permissions",
@@ -798,13 +819,16 @@ impl<'de> Deserialize<'de> for Guild {
 mod tests {
     use super::{
         ApplicationId, ChannelId, DefaultMessageNotificationLevel, ExplicitContentFilter, Guild,
-        GuildId, MfaLevel, Permissions, PremiumTier, SystemChannelFlags, UserId, VerificationLevel,
+        GuildId, MfaLevel, NSFWLevel, Permissions, PremiumTier, SystemChannelFlags, UserId,
+        VerificationLevel,
     };
     use serde_test::Token;
 
     #[allow(clippy::too_many_lines)]
+    #[allow(deprecated)]
     #[test]
     fn test_guild() {
+        #[allow(deprecated)]
         let value = Guild {
             afk_channel_id: Some(ChannelId(2)),
             afk_timeout: 900,
@@ -831,6 +855,7 @@ mod tests {
             mfa_level: MfaLevel::Elevated,
             name: "the name".to_owned(),
             nsfw: false,
+            nsfw_level: NSFWLevel::Default,
             owner_id: UserId(5),
             owner: Some(false),
             permissions: Some(Permissions::SEND_MESSAGES),
@@ -842,6 +867,7 @@ mod tests {
             roles: Vec::new(),
             rules_channel_id: Some(ChannelId(6)),
             splash: Some("splash hash".to_owned()),
+            stage_instances: Vec::new(),
             system_channel_flags: SystemChannelFlags::SUPPRESS_PREMIUM_SUBSCRIPTIONS,
             system_channel_id: Some(ChannelId(7)),
             unavailable: false,
@@ -930,8 +956,8 @@ mod tests {
                 Token::U8(1),
                 Token::Str("name"),
                 Token::Str("the name"),
-                Token::Str("nsfw"),
-                Token::Bool(false),
+                Token::Str("nsfw_level"),
+                Token::U8(0),
                 Token::Str("owner_id"),
                 Token::NewtypeStruct { name: "UserId" },
                 Token::Str("5"),
