@@ -1,6 +1,5 @@
+pub mod current_application_info;
 pub mod id;
 pub mod team;
 
-mod current_application_info;
-
 pub use self::current_application_info::CurrentApplicationInfo;
